==> v1.18.1.tar.gz: detekt-1.18.1/detekt-rules-coroutines/src/test/kotlin/io/gitlab/arturbosch/detekt/rules/coroutines/SleepInsteadOfDelaySpec.kt <==
package io.gitlab.arturbosch.detekt.rules.coroutines

import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.rules.setupKotlinEnvironment
import io.gitlab.arturbosch.detekt.test.compileAndLintWithContext
import org.assertj.core.api.Assertions.assertThat
import org.jetbrains.kotlin.cli.jvm.compiler.KotlinCoreEnvironment
import org.spekframework.spek2.Spek
import org.spekframework.spek2.style.specification.describe

@Suppress("BlockingMethodInNonBlockingContext", "RedundantSuspendModifier")
object SleepInsteadOfDelaySpec : Spek({
    setupKotlinEnvironment()

    val env: KotlinCoreEnvironment by memoized()
    val subject by memoized { SleepInsteadOfDelay(Config.empty) }

    describe("SleepInsteadOfDelay rule") {
        it("should report no issue for delay() in suspend functions") {
            val code = """
                import kotlinx.coroutines.delay

                suspend fun foo() {
                    delay(1000L)
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(0)
        }

        it("should report Thread.sleep() in suspend functions") {
            val code = """
                suspend fun foo() {
                    Thread.sleep(1000L)
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }

        it("should report Thread.sleep() in CoroutineScope.launch()") {
            val code = """
                import kotlinx.coroutines.CoroutineScope
                import kotlinx.coroutines.Dispatchers
                import kotlinx.coroutines.launch
                
                fun foo() {
                    CoroutineScope(Dispatchers.IO).launch {
                        Thread.sleep(1000L)
                    }
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }

        it("should report Thread.sleep() in CoroutineScope.async()") {
            @Suppress("DeferredResultUnused")
            val code = """
                import kotlinx.coroutines.CoroutineScope
                import kotlinx.coroutines.Dispatchers
                import kotlinx.coroutines.async
                
                fun foo() {
                    CoroutineScope(Dispatchers.IO).async {
                        Thread.sleep(1000L)
                    }
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }
    }
})

==> v1.20.0.tar.gz: detekt-1.20.0/detekt-rules-coroutines/src/test/kotlin/io/gitlab/arturbosch/detekt/rules/coroutines/SleepInsteadOfDelaySpec.kt <==
package io.gitlab.arturbosch.detekt.rules.coroutines

import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.rules.KotlinCoreEnvironmentTest
import io.gitlab.arturbosch.detekt.test.compileAndLintWithContext
import org.assertj.core.api.Assertions.assertThat
import org.jetbrains.kotlin.cli.jvm.compiler.KotlinCoreEnvironment
import org.junit.jupiter.api.DisplayName
import org.junit.jupiter.api.Nested
import org.junit.jupiter.api.Test

@Suppress("BlockingMethodInNonBlockingContext", "RedundantSuspendModifier")
@KotlinCoreEnvironmentTest
class SleepInsteadOfDelaySpec(val env: KotlinCoreEnvironment) {

    val subject = SleepInsteadOfDelay(Config.empty)

    @Nested
    inner class `SleepInsteadOfDelay rule` {
        @Test
        fun `should report no issue for delay() in suspend functions`() {
            val code = """
                import kotlinx.coroutines.delay

                suspend fun foo() {
                    delay(1000L)
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(0)
        }

        @Test
        @DisplayName("should report Thread.sleep() in suspend functions")
        fun reportThreadSleepInSuspendFunctions() {
            val code = """
                suspend fun foo() {
                    Thread.sleep(1000L)
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }

        @Test
        @DisplayName("should report Thread.sleep() in CoroutineScope.launch()")
        fun reportThreadSleepInCoroutineScopeLaunch() {
            val code = """
                import kotlinx.coroutines.CoroutineScope
                import kotlinx.coroutines.Dispatchers
                import kotlinx.coroutines.launch
                
                fun foo() {
                    CoroutineScope(Dispatchers.IO).launch {
                        Thread.sleep(1000L)
                    }
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }

        @Test
        @DisplayName("should report Thread.sleep() in CoroutineScope.async()")
        fun reportThreadSleepInCoroutineScopeAsync() {
            @Suppress("DeferredResultUnused")
            val code = """
                import kotlinx.coroutines.CoroutineScope
                import kotlinx.coroutines.Dispatchers
                import kotlinx.coroutines.async
                
                fun foo() {
                    CoroutineScope(Dispatchers.IO).async {
                        Thread.sleep(1000L)
                    }
                }
            """
            assertThat(subject.compileAndLintWithContext(env, code)).hasSize(1)
        }
    }
}
